@@ -1,22 +1,8 @@
-###############################################################################
-#
-# Tie::iCal
-#
-# 18 Jan 2005 by Blair Sutton <bsdz@cpan.org>
-#
-# Version: 0.12 (27th January 2005)
-#
-# Copyright (c) 2005 Blair Sutton. All rights reserved.
-# This program is free software; you can redistribute it and/or
-# modify it under the same terms as Perl itself.
-#
-###############################################################################
-
 package Tie::iCal;
 
 use strict;
 require Exporter;
-our $VERSION = 0.12;
+our $VERSION = 0.14;
 our @ISA     = qw(Exporter);
 
 use Tie::File;
@@ -25,6 +11,10 @@ use Tie::File;
 
 Tie::iCal - Tie iCal files to Perl hashes.
 
+=head1 VERSION
+
+This document describes version 0.14 released 1st September 2006.
+
 =head1 SYNOPSIS
 
 	use Tie::iCal;
@@ -80,6 +70,12 @@ This may be useful for file locking.
 	my $ical = tie %events, 'Tie::iCal', "mycalendar.ics";
 	$ical->{A}->flock;
 
+=head1 DATES
+
+The iCalendar specification uses a special format for dates. This module makes no effort in trying
+to interpret dates in this format. You should look at the Date::ICal module that can convert between
+Unix epoch dates and iCalendar date strings.
+
 =cut
 
 sub TIEHASH {
@@ -116,12 +112,12 @@ sub FIRSTKEY {
 	
 	$self->{i} = 0;
 	for my $line (@{$self->{A}}) {
-		if ($line =~ m/^UID/) {
+		if (substr($line, 0, 3) eq 'UID') {
 			if ($self->unfold($self->{i}) =~ /^UID.*:(.*)$/) {
 				$self->{C}->{$1} = $self->{i}; # cache in any case
 				return $1;
 			} else {
-				warn("FISRTKEY: discovered illegal UID property format, should be like UID;...:..., ignoring for now\n");
+				warn("FIRSTKEY: discovered illegal UID property format, should be like UID;...:..., ignoring for now\n");
 			}
 		}
 		$self->{i}++;
@@ -136,7 +132,7 @@ sub NEXTKEY {
 	my $i = $self->{i};
 	$self->{i} = 0;
 	for my $line (@{$self->{A}}) {
-		if ($line =~ m/^UID/ && $self->{i} > $i) {
+		if ($self->{i} > $i && substr($line, 0, 3) eq 'UID') {
 			if ($self->unfold($self->{i}) =~ /^UID.*:(.*)$/) {
 				$self->{C}->{$1} = $self->{i}; # cache in any case
 				return $1;
@@ -154,7 +150,7 @@ sub SCALAR {
 	
 	my $count = 0;
 	for my $line (@{$self->{A}}) {
-		$count++ if $line =~ m/^UID/;
+		$count++ if substr($line, 0, 3) eq 'UID';
 	}
 	return $count;
 }
@@ -216,7 +212,7 @@ sub unfold {
 	
 	my $result = ${$self->{A}}[$index];
 	my $i = 1;
-	until (${$self->{A}}[$index + $i] !~ /^ (.*)$/) {
+	until (${$self->{A}}[$index + $i] !~ /^ (.*)$/s) {
 		$result .= $1;
 		$i++;
 	}
@@ -252,7 +248,7 @@ sub seekUid {
 	#
 	$index = 0;
 	for my $line (@{$self->{A}}) {
-		if ($line =~ m/^UID/) {
+		if (substr($line, 0, 3) eq 'UID') {
 			if ($self->unfold($index) =~ /^UID.*:(.*)$/) {
 				$self->{C}->{$1} = $index; # cache in any case
 				if ($1 eq $uid) {
@@ -363,6 +359,14 @@ having an equivalent perl data structure like: -
 
     'NAME' => 'VALUE'
 
+An blank value is mapped from
+
+	NAME:
+
+to 
+
+	'NAME' => ''
+
 Multiple contentlines with same name, i.e. FREEBUSY, ATTENDEE:-
 
     NAME;PARAM10=PVAL10;PARAM20=PVAL20;...:VALUE10,VALUE20,...
@@ -520,7 +524,7 @@ sub toHash {
 			} elsif ($contentLine =~ /^BEGIN:(\w+)$/) { # we have found a subcomponent
 				$subComponent = $1;
 				push @{$e{$subComponent}}, $self->toHash($i, 1);
-			} elsif ($contentLine =~ /^[\w-]+;.*$/) { # we have params
+			} elsif ($contentLine =~ /^[\w-]+;.*$/s) { # we have params
 				my ($nameAndParamString, @valueFragments) = &parse_line(':', $contentLine);
 				my @values = &parse_line(',', join(':', @valueFragments));
 				my ($name, @params) = &parse_line(';', $nameAndParamString);
@@ -535,7 +539,7 @@ sub toHash {
                 } else {
                     $e{$name} = [{%params}, @values];
                 }
-			} elsif ($contentLine =~ /^[\w-]+:.*$/) { # we don't have params
+			} elsif ($contentLine =~ /^[\w-]+:.*$/s) { # we don't have params
 				my ($name, @valueFragments) = &parse_line(':', $contentLine);
 				my @values;
 				if ($name eq 'RRULE') {
@@ -553,7 +557,13 @@ sub toHash {
                         push @{$e{$name}}, [@values];
                     }
                 } else {
-                    $e{$name} = @values == 1 ? $values[0] : [@values];
+					if (@values == 0) {
+                    	$e{$name} = "";
+					} elsif (@values == 1)  {
+						$e{$name} = $values[0];
+					} else {
+						$e{$name} = [@values];
+					}
                 }
 			} else { # what do we have?
 				warn("discovered illegal property format, should be like NAME;...:..., ignoring for now\n");
@@ -579,6 +589,19 @@ Subcomponents such as VALARM must exist after any UID property.
 
 Deleting events individually may leave non-RFC2445 compliant empty VCALENDAR objects.
 
+=head1 AUTHOR
+
+Blair Sutton, <mailto:bsdz@cpan.org>, L<http://www.numeninest.com/>
+
+=head1 COPYRIGHT
+
+Copyright (c) 2006 Blair Sutton. All rights reserved.
+This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+
+=head1 SEE ALSO
+
+L<perl>, L<Tie::File>, L<Date::ICal>
+
 =cut
 
 1;
\ No newline at end of file
